// ml - A media library representation.

// Copyright (C) 2005-2006 Editopia Inc.
// Released under the LGPL.
// For more information, see http://www.openlibraries.org.

#ifndef PY_INC_
#define PY_INC_

namespace olib { namespace openmedialib { namespace ml { namespace detail {

void py_input( );
void py_store( );
void py_frame( );
void py_audio( );
void py_audio_reseat( );
void py_filter( );
void py_plugin( );
void py_stream( );

} } } }

#endif
